# Kognic Base Clients

Python 3 library for providing a base clients for interacting with the Kognic platform

# Changelog

All notable changes to this library will be documented in this file


## [1.1.0] - 2023-05-10

- Failed requests will be retried in a wider range of cases than previously, including both API calls and cloud storage.

## [1.0.3] - 2022-12-02

- Improve handling of network errors during file uploads. TCP and SSL timeout errors will now result in retries.

## [1.0.2] - 2022-11-01
- Internal re-work of scene upload handling to allow uploaded bytes from other sources than files
- Removed an unused argument from some internal methods.

## [1.0.1] - 2022-11-01
- Added string type as an option for cursor id 

## [1.0.0] - 2022-10-18
- Annotell becomes Kognic

## [0.1.1] - 2022-08-16
- Corrected user agent
- Bugfix for timeout

## [0.1.0] - 2022-05-12
- Update `annotell-auth` to 2.0.1
- Support for pagination on API requests

## [0.0.1] - 2022-04-01

- Library created
